package cn.iocoder.yudao.module.jx.service;

import cn.iocoder.yudao.module.jx.domain.DriveCarBind;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;

import java.util.List;

/**
 * 车辆绑定（教练）Service接口
 *
 * @author ruoyi
 * @date 2024-04-01
 */
public interface IDriveCarBindService
{
    /**
     * 查询车辆绑定（教练）
     *
     * @param id 车辆绑定（教练）主键
     * @return 车辆绑定（教练）
     */
    public DriveCarBind selectDriveCarBindById(Long id);

    /**
     * 查询车辆绑定（教练）列表
     *
     * @param driveCarBind 车辆绑定（教练）
     * @return 车辆绑定（教练）集合
     */
    public IPage<DriveCarBind> selectDriveCarBindList(DriveCarBind driveCarBind, Page<DriveCarBind> page);

    /**
     * 新增车辆绑定（教练）
     *
     * @param driveCarBind 车辆绑定（教练）
     * @return 结果
     */
    public int insertDriveCarBind(DriveCarBind driveCarBind);

    /**
     * 修改车辆绑定（教练）
     *
     * @param driveCarBind 车辆绑定（教练）
     * @return 结果
     */
    public int updateDriveCarBind(DriveCarBind driveCarBind);

    /**
     * 批量删除车辆绑定（教练）
     *
     * @param ids 需要删除的车辆绑定（教练）主键集合
     * @return 结果
     */
    public int deleteDriveCarBindByIds(Long[] ids);

    /**
     * 删除车辆绑定（教练）信息
     *
     * @param id 车辆绑定（教练）主键
     * @return 结果
     */
    public int deleteDriveCarBindById(Long id);
}
